==> kuroo-0.90.5_p20180410.tar.xz: kuroo-0.90.5_p20180410/src/core/dependencyview.h <==
/***************************************************************************
*	Copyright (C) 2004 by karye												*
*	karye@users.sourceforge.net												*
*																			*
*	This program is free software; you can redistribute it and/or modify	*
*	it under the terms of the GNU General Public License as published by	*
*	the Free Software Foundation; either version 2 of the License, or		*
*	(at your option) any later version.										*
*																			*
*	This program is distributed in the hope that it will be useful,			*
*	but WITHOUT ANY WARRANTY; without even the implied warranty of			*
*	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the			*
*	GNU General Public License for more details.							*
*																			*
*	You should have received a copy of the GNU General Public License		*
*	along with this program; if not, write to the							*
*	Free Software Foundation, Inc.,											*
*	59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.				*
***************************************************************************/

#ifndef DEPENDENCYVIEW_H
#define DEPENDENCYVIEW_H

#include <QTreeWidget>

/**
 * @class DependencyView
 * @short Listview to build dependency-tree view.
 */
class DependencyView : public QTreeWidget
{
Q_OBJECT
public:
	DependencyView( QWidget *parent = 0/*, const char *name = 0 */);
	~DependencyView();

	class 			DependencyItem;

	void			insertDependAtoms( const QStringList& dependAtomsList );

private slots:
	void			slotPackageClicked( QTreeWidgetItem* item );

};

#endif

==> kuroo-1.2.4.tar.xz: kuroo-1.2.4/src/core/dependencyview.h <==
/***************************************************************************
*	Copyright (C) 2004 by karye												*
*	karye@users.sourceforge.net												*
*																			*
*	This program is free software; you can redistribute it and/or modify	*
*	it under the terms of the GNU General Public License as published by	*
*	the Free Software Foundation; either version 2 of the License, or		*
*	(at your option) any later version.										*
*																			*
*	This program is distributed in the hope that it will be useful,			*
*	but WITHOUT ANY WARRANTY; without even the implied warranty of			*
*	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the			*
*	GNU General Public License for more details.							*
*																			*
*	You should have received a copy of the GNU General Public License		*
*	along with this program; if not, write to the							*
*	Free Software Foundation, Inc.,											*
*	59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.				*
***************************************************************************/

#ifndef DEPENDENCYVIEW_H
#define DEPENDENCYVIEW_H

#include <QTreeWidget>

/**
 * @class DependencyView
 * @short Listview to build dependency-tree view.
 */
class DependencyView : public QTreeWidget
{
Q_OBJECT
public:
	DependencyView( QWidget *parent = nullptr/*, const char *name = 0 */);
	~DependencyView();

	class 			DependencyItem;

	void			insertDependAtoms( const QStringList& dependAtomsList );

private Q_SLOTS:
	static void			slotPackageClicked( QTreeWidgetItem* item );

};

#endif
